@@ -2,7 +2,7 @@ from Acquisition import aq_inner
 from Products.Five.browser import BrowserView
 
 class rsscodeView(BrowserView):
-    js_code = "jq(document).ready(function () {jq('#rsscontainer').rssfeed('%s', {limit: %s});});"
+    js_code = "$(document).ready(function () {$('#rsscontainer').rssfeed('%s', {limit: %s});});"
     def __call__(self,REQUEST,RESPONSE):
         context = aq_inner(self.context)
         RESPONSE.setHeader('Content-Type', 'application/javascript')
